
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
#
# To compare versions robustly, use `numpy.lib.NumpyVersion`
short_version = '1.16.6'
version = '1.16.6'
full_version = '1.16.6'
git_revision = '3dec7099ce38cb189880f6f69df318f35ff9a5ea'
release = True

if not release:
    version = full_version
